chordtools.Chord
================

.. inheritance-diagram:: abjad.tools.chordtools.Chord.Chord.Chord
   :private-bases:

.. autoclass:: abjad.tools.chordtools.Chord.Chord.Chord

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.duration_in_seconds

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.fingered_pitches

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.leaf_index

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.lilypond_format

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.multiplied_duration

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.override

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.parent

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.preprolated_duration

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.prolated_duration

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.prolation

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.set

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.sounding_pitches

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.spanners

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.start_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.start_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.stop_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.stop_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.duration_multiplier

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.note_heads

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_duration

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_pitch_indication_is_at_sounding_pitch

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_pitch_indication_is_nonsemantic

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_pitches

Methods
-------

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.append

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.clear

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.extend

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.pop

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.remove

Special Methods
---------------

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__and__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__contains__

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__delitem__

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__getitem__

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__len__

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__mul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__or__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__repr__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__rmul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__setitem__

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__str__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__sub__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__xor__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`
